from setuptools import setup

setup(
    name="mekartify",
    version="0.1.1",
    description="Mekartify some tool for optimize computations",
    author="Sugeng D. Cahyo",
    packages=[],
    install_requires=[]
)
